@@ -8,8 +8,10 @@ from __future__ import annotations
 
 from collections import ChainMap
 from enum import Enum
-from typing import TYPE_CHECKING, Optional, Any, Union, Callable, Type, TypeVar, Generic, overload, Dict
+from string import whitespace
+from typing import TYPE_CHECKING, Any, Callable, Generic, Optional, Sequence, Type, TypeVar, Union, overload
 
+from .exceptions import CommandDefinitionError
 from .utils import FixedFlag, MissingMixin, _NotSet, positive_int
 
 if TYPE_CHECKING:
@@ -17,7 +19,7 @@ if TYPE_CHECKING:
     from .error_handling import ErrorHandler
     from .formatting.commands import CommandHelpFormatter
     from .formatting.params import ParamHelpFormatter
-    from .typing import Bool, ParamOrGroup, CommandType
+    from .typing import Bool, CommandType, ParamOrGroup
 
 __all__ = [
     'CommandConfig',
@@ -49,11 +51,13 @@ class ShowDefaults(FixedFlag):
     is equivalent to ``ShowDefaults.MISSING | ShowDefaults.NEVER``, which will result in no default values being shown.
     """
 
+    # fmt: off
     NEVER = 1       #: Never include the default value in help text
     MISSING = 2     #: Only include the default value if ``default:`` is not already present
     TRUTHY = 4      #: Only include the default value if it is treated as True in a boolean context
     NON_EMPTY = 8   #: Only include the default value if it is not ``None`` or an empty container
     ANY = 16        #: Any default value, regardless of truthiness, will be included
+    # fmt: on
 
     @classmethod
     def _missing_(cls, value: Union[str, int]) -> ShowDefaults:
@@ -104,6 +108,7 @@ class OptionNameMode(FixedFlag):
         - ``'underscore'`` or ``'dash'`` or ``'both'`` or ``'both_underscore'`` or ``'both_dash'`` or ``'none'``
     """
 
+    # fmt: off
     UNDERSCORE = 1
     DASH = 2
     BOTH = 3                # = 1|2
@@ -111,6 +116,7 @@ class OptionNameMode(FixedFlag):
     BOTH_UNDERSCORE = 15    # & 8  -> show only underscore version
     BOTH_DASH = 23          # & 16 -> show only dash version
     NONE = 32
+    # fmt: on
 
     @classmethod
     def _missing_(cls, value: Union[str, int, None]) -> OptionNameMode:
@@ -153,9 +159,11 @@ class SubcommandAliasHelpMode(MissingMixin, Enum):
       ``Alias of: <first choice/alias value>``.
     """
 
+    # fmt: off
     REPEAT = 'repeat'       # Repeat the description as if it was a separate subcommand
     COMBINE = 'combine'     # Combine aliases onto a single line
     ALIAS = 'alias'         # Indicate the subcommand that it is an alias for; do not repeat the description
+    # fmt: on
 
 
 CmdAliasMode = Union[SubcommandAliasHelpMode, str]
@@ -176,9 +184,11 @@ class AmbiguousComboMode(MissingMixin, Enum):
       input.
     """
 
+    # fmt: off
     IGNORE = 'ignore'           # Ignore potentially ambiguous combinations of short options entirely
     PERMISSIVE = 'permissive'   # Allow multi-char short options that overlap with a single char one for exact matches
     STRICT = 'strict'           # Reject multi-char short options that overlap with a single char one before parsing
+    # fmt: on
 
 
 class AllowLeadingDash(Enum):
@@ -193,9 +203,11 @@ class AllowLeadingDash(Enum):
     :NEVER: Never allow values with a leading dash.
     """
 
+    # fmt: off
     NUMERIC = 'numeric'     # Allow a leading dash when the value is numeric
     ALWAYS = 'always'       # Always allow a leading dash
     NEVER = 'never'         # Never allow a leading dash
+    # fmt: on
 
     @classmethod
     def _missing_(cls, value):
@@ -218,6 +230,13 @@ class AllowLeadingDash(Enum):
 
 
 class ConfigItem(Generic[CV, DV]):
+    """
+    A single configurable setting in the :class:`CommandConfig`.
+
+    :param default: Default config value to use if no explicit value is provided
+    :param type: A class or other callable that will be called to validate/normalize provided values
+    """
+
     __slots__ = ('default', 'type', 'name')
 
     def __init__(self, default: DV, type: Callable[..., CV] = None):  # noqa
@@ -229,17 +248,16 @@ class ConfigItem(Generic[CV, DV]):
         owner.FIELDS.add(name)
 
     @overload
-    def __get__(self, instance: None, owner: Type[CommandConfig]) -> ConfigItem[CV, DV]:
-        ...
+    def __get__(self, instance: None, owner: Type[CommandConfig]) -> ConfigItem[CV, DV]: ...
 
     @overload
-    def __get__(self, instance: CommandConfig, owner: Type[CommandConfig]) -> ConfigValue:
-        ...
+    def __get__(self, instance: CommandConfig, owner: Type[CommandConfig]) -> ConfigValue: ...
 
     def __get__(self, instance, owner):
-        if instance is None:
+        try:
+            return instance._data.get(self.name, self.default)
+        except AttributeError:  # instance is None
             return self
-        return instance._data.get(self.name, self.default)
 
     def __set__(self, instance: CommandConfig, value: ConfigValue):
         if instance._read_only:
@@ -261,6 +279,8 @@ class ConfigItem(Generic[CV, DV]):
 
 
 class DynamicConfigItem(ConfigItem):
+    # A ConfigItem with a setter :paramref:`.ConfigItem.type` defined as a method in :class:`CommandConfig`.
+
     __slots__ = ('__doc__',)
 
     def __init__(self, default: DV, type: Callable[..., CV]):  # noqa
@@ -372,6 +392,35 @@ class CommandConfig:
     #: Whether there should be a visual indicator in help text for the parameters that are members of a given group
     show_group_tree: Bool = ConfigItem(False, bool)
 
+    @config_item(('\u00a6 ', '\u2551 ', '\u2502 '))
+    def group_tree_spacers(self, value: tuple[str, str, str] | Sequence[str]) -> tuple[str, str, str]:
+        """
+        The spacer characters to use at the beginning of each line when :attr:`.show_group_tree` is True.
+
+        The default spacers:
+
+        +--------------------+-----------+------------------------------+
+        | Parameter Type     | Character | Character Name               |
+        +====================+===========+==============================+
+        | Mutually Exclusive | \u00a6         | BROKEN BAR                   |
+        +--------------------+-----------+------------------------------+
+        | Mutually dependent | \u2551         | BOX DRAWINGS DOUBLE VERTICAL |
+        +--------------------+-----------+------------------------------+
+        | Other              | \u2502         | BOX DRAWINGS LIGHT VERTICAL  |
+        +--------------------+-----------+------------------------------+
+
+        :param value: A 3-tuple (or other sequence with 3 items) of spacer strings to be used for
+          (mutually exclusive, mutually dependent, other) group members, respectively.
+        :return: The validated and normalized value (or the default value if this property is accessed without
+          providing explicit values)
+        """
+        # Note: extra spaces in the docstring table are intentional - the escape sequences each collapse to one char
+        if isinstance(value, Sequence) and len(value) == 3 and all(isinstance(v, str) for v in value):
+            return tuple(f'{v} ' if v and v[-1] not in whitespace else v for v in value)  # noqa
+        raise CommandDefinitionError(
+            f'Invalid group_tree_spacers={value!r} - expected a 3-tuple of 2-character strings'
+        )
+
     #: Whether mutually exclusive / dependent groups should include that fact in their descriptions
     show_group_type: Bool = ConfigItem(True, bool)
 
@@ -386,16 +435,17 @@ class CommandConfig:
     #: they were successfully detected
     extended_epilog: Bool = ConfigItem(True, bool)
 
-    #: Width (in characters) for the usage column in help text
+    #: Width (in characters) for the usage column in help text, after which the parameter descriptions begin.
     usage_column_width: int = ConfigItem(30, int)
 
-    #: Min width (in chars) for the usage column in help text after adjusting for group indentation / terminal width
-    min_usage_column_width: int = ConfigItem(20, int)
+    #: Whether the :attr:`.usage_column_width` should be enforced for parameters with usage text parts that exceed it.
+    #: By default, that setting only defines where the parameter descriptions begin.
+    strict_usage_column_width: bool = ConfigItem(False, bool)
 
     @config_item(False)
     def wrap_usage_str(self, value: Any) -> Union[int, bool]:
         """
-        Wrap the basic usage string after the specified number of characters, or automatically based on terminal size
+        Wrap the basic usage line after the specified number of characters, or automatically based on terminal size
         if ``True`` is specified instead.
         """
         if value is True or value is False:
@@ -432,7 +482,7 @@ class CommandConfig:
         settings = ', '.join(f'{k}={v!r}' for k, v in self.as_dict(False).items())
         return f'<{self.__class__.__name__}[depth={len(self._data.maps)}]({settings})>'
 
-    def as_dict(self, full: Bool = True) -> Dict[str, Any]:
+    def as_dict(self, full: Bool = True) -> dict[str, Any]:
         """Return a dict representing the configured options."""
         if full:
             return {key: getattr(self, key) for key in self.FIELDS}
